import React, { Component } from "react";
import axios from "axios";
import "bootstrap/dist/css/bootstrap.min.css";
import * as FPUtils from "../../fp-utils.js";
import * as Flashphoner from "@flashphoner/websdk";

const SESSION_STATUS = Flashphoner.constants.SESSION_STATUS;
const STREAM_STATUS = Flashphoner.constants.STREAM_STATUS;
const Browser = Flashphoner.Browser;
const PRELOADER_URL = process.env.PUBLIC_URL + "/media/preloader.mp4";
var CONNECTION_QUALITY = Flashphoner.constants.CONNECTION_QUALITY;
var CONNECTION_QUALITY_UPDATE_TIMEOUT_MS = 10000;
var STAT_INTERVAL = 1000;
var videoBytesSent = 0;
var audioBytesSent = 0;
var publishConnectionQualityStat = {};
var micLevelInterval;
var audioContextForTest;
var testStarted;

class Home extends Component {
  constructor(props) {
    super(props);
    this.state = {
      apiFailed: "",
      session: null,
      sessionStatus: "",
      sessionStatusClass: "text-muted",
      localVideo:null,
      remoteVideo: null,
      publishStream: null,
      publishStatus: "",
      publishStatusClass: "text-muted",
      playStream: null,
      playStatus: "",
      playStatusClass: "text-muted",
      publishStreamName: "streamName",
      publishStreamNameDisabled: true,
      playStreamName: "streamName",
      playStreamNameDisabled: true,
      connectButtonText: "Connect to server",
      connectButtonDisabled: false,
      //serverUrl: 'wss://gpurack.easestream.com:8443/',
      //serverUrl: 'wss://aws.easestream.com:8443',
      serverUrl: "wss://awscpu.easestream.com:8443",
      serverUrlDisabled: false,
      publishButtonText: "Publish",
      publishButtonDisabled: true,
      playButtonText: "Play",
      playButtonDisabled: true,
      muteAudioButtonText: "Mute Audio",
      muteAudioButtonDisabled: false,
      muteVideoButtonText: "Mute Video",
      muteVideoButtonDisabled: false,
      minBitrate: "1000",
      maxBitrate: "2000",
      frameRate: "30",
      width: "1280",
      height: "720",
      recordFileName: null,
      outboundStreamValue: '',
      audio: true, // Set your default audio value
      video: true, // Set your default video value
      testButtonText:"Test Camera",
    };
    this.localVideoRef = React.createRef(); 
    
  }
 
  componentDidMount = async() => {
    
    try {
      Flashphoner.init({});
      const localVideo = this.localVideoRef.current
      this.setState({
        localVideo: document.getElementById("localVideo"),
        remoteVideo: document.getElementById("remoteVideo"),
      });

     await Flashphoner.getMediaAccess(this.getConstraints(), localVideo);
      const audioContext = new (window.AudioContext || window.webkitAudioContext)();
      if (Flashphoner.getMediaProviders()[0] === "WebRTC" && audioContext) {
        for (let i = 0; i < localVideo.children.length; i++) {
          const videoChild = localVideo.children[i];
           if (videoChild && videoChild.id.indexOf("-LOCAL_CACHED_VIDEO") !== -1) {
               const stream = videoChild.srcObject;
               console.log("stream",stream);
           }
        }
      }
  
    
    } catch (e) {
      console.log(e);
      this.setState({
        apiFailed:
          "Your browser does not support WebRTC technology needed for this example",
        connectButtonDisabled: true,
        serverUrlDisabled: true,
      });
    }
 
    this.onConnectClick();
    
  
    Flashphoner.getMediaDevices(null, true).then(function (list) {
      //Get a list of available Microphone
      list.audio.forEach(function (device) {
        //List filling
        var audio = document.getElementById("audioInput");
        var deviceInList = false;
        for (var i = 0; i < audio.options.length; i++) {
          if (audio.options[i].value === device.id) {
            deviceInList = true;
            break;
          }
        }
        if (!deviceInList) {
          var option = document.createElement("option");
          option.text = device.label || device.id;
          option.value = device.id;
          audio.appendChild(option);
        }
      });
      //Get a list of available Camera
      list.video.forEach(function (device) {
        //List filling
        var video = document.getElementById("videoInput");
        var deviceInList = false;
        for (var i = 0; i < video.options.length; i++) {
          if (video.options[i].value === device.id) {
            deviceInList = true;
            break;
          }
        }
        if (!deviceInList) {
          var option = document.createElement("option");
          option.text = device.label || device.id;
          option.value = device.id;
          if (
            option.text.toLowerCase().indexOf("back") >= 0 &&
            video.children.length > 0
          ) {
            video.insertBefore(option, video.children[0]);
          } else {
            video.appendChild(option);
          }
        }
      });
    });

 
  }

  getStremdata = () => {
    axios({
      method: "POST",
      url: "https://awscpu.easestream.com:8444/rest-api/stream/find_all",
      headers: {
        "content-type": "application/json",
        Accept: "application/json",
      },
      body: JSON.stringify({
        name: "stream1",
        published: true,
      }),
    })
      .then((response) => {
        console.log(response);
        console.log(response.request);
      })
      .catch((error) => {
        console.log(error);
      });
  };

  onConnected = (session) => {
    this.setState({
      session: session,
      connectButtonText: "Disconnect to server",
      connectButtonDisabled: false,
      serverUrlDisabled: true,
    });

   
    this.onUnpublished();
    this.onStopped();
   
  };


  onDisconnected = () => {
    this.setState({
      session: null,
      connectButtonText: "Connect to server",
      connectButtonDisabled: false,
      serverUrlDisabled: false,
    });
    this.onUnpublished();
    this.onStopped();
  };

  onPublishing = (stream) => {
    let app = this;
    let publishStream = stream;
    let publishStatsIntervalID = this.state.publishStatsIntervalID;
    if (!publishStatsIntervalID) {
      console.log("Start WebRTC statistics collection");
      publishStatsIntervalID = setInterval(() => {
        app.loadPublishStats(publishStream);
      }, STAT_INTERVAL);
    }
    

    this.setState({
      publishStream: stream,
      publishButtonText: "Unpublish",
      publishButtonDisabled: false,
    });
    this.showDownloadLink();
    this.stopTest();
  };

  onUnpublished = () => {
    let session = this.state.session;
    let itemState = true;
    if (session && session.status() === SESSION_STATUS.ESTABLISHED) {
      itemState = false;
    }

    this.setState({
      publishStream: null,
      publishButtonText: "Publish",
      publishButtonDisabled: itemState,
      publishStreamNameDisabled: itemState,
      
    });
   // this.stopTest();
    };


  onPlaying = (stream) => {
    this.setState({
      playStream: stream,
      playButtonText: "Stop",
      playButtonDisabled: false,
    });
  };

  onStopped = () => {
    let session = this.state.session;
    let itemState = true;

    if (session && session.status() === SESSION_STATUS.ESTABLISHED) {
      itemState = false;
    }
    this.setState({
      playStream: null,
      playButtonText: "Play",
      playButtonDisabled: itemState,
      playStreamNameDisabled: itemState,
    });
  };

  publishStream = () => {
    let app = this;
    let session = this.state.session;
    let streamName = this.state.publishStreamName;
    let localVideo = this.state.localVideo;
    var constraints = this.getConstraints();
    if (session && localVideo) {
      session
        .createStream({
          name: streamName,
          display: localVideo,
          cacheLocalResources: true,
          receiveVideo: true,
          receiveAudio: true,
          useControls: false,
          record: true,
          constraints: constraints,
          recordDisplay: true,
          videoContentHint: "detail",
          transport: "TCP",
          
          constraints: {
            video: {
              deviceId: document.getElementById("videoInput").value,
              width: document.getElementById("sendWidth").value,
              height: document.getElementById("sendHeight").value,
              minBitrate: document.getElementById("sendBitrateMin").value,
              maxBitrate: document.getElementById("sendBitrateMax").value,
              frameRate: document.getElementById("sendFPS").value,
              //  gainValue: document.getElementById("sendGain").value,
            },
            audio: {
              deviceId: document.getElementById("audioInput").value,
              //gainValue: document.getElementById("sendGain").value,
            },
          },
        })
        .on(STREAM_STATUS.PUBLISHING, (stream) => {
          app.setState({
            publishStatus: STREAM_STATUS.PUBLISHING,
            publishStatusClass: "text-success",
          });

          app.onPublishing(stream);
          app.getStremdata(stream);
          //this.stopTest();
        })
        .on(STREAM_STATUS.UNPUBLISHED, (stream) => {
          app.setState({
            publishStatus: STREAM_STATUS.UNPUBLISHED,
            publishStatusClass: "text-success",
          });

          app.showDownloadLink(stream.getRecordInfo());
          app.onUnpublished();
       
        })
        .on(STREAM_STATUS.FAILED, (stream) => {
          app.setState({
            publishStatus: STREAM_STATUS.FAILED,
            publishStatusClass: "text-danger",
          });
          app.showDownloadLink(stream.getRecordInfo());
          app.onUnpublished();
        })
        .publish();
    }
  };


loadPublishStats = (stream) => {
  if (stream) {
    stream.getStats((stats) => {
      if (stats && stats.outboundStream) {
        const outboundStreamValue = JSON.stringify(stats.outboundStream);
        this.setState({ outboundStreamValue });

        if (stats.outboundStream.video) {
          this.showStat(stats.outboundStream.video, "outVideoStat");
          let vBitrate = (stats.outboundStream.video.bytesSent - videoBytesSent) * 8;
          if (!document.getElementById('outVideoStatBitrate')) {
            let html = "<div>Video Bitrate(Kbps): " + "<span id='outVideoStatBitrate' style='font-weight: normal'>" + vBitrate + "</span>" + "</div>";
            document.getElementById("outVideoStat").insertAdjacentHTML('beforeend', html);
          } else {
            document.getElementById('outVideoStatBitrate').innerText = vBitrate;
          
          }
          videoBytesSent = stats.outboundStream.video.bytesSent;

          if(new Date().valueOf() - CONNECTION_QUALITY_UPDATE_TIMEOUT_MS > publishConnectionQualityStat.connectionQualityUpdateTimestamp) {
              publishConnectionQualityStat.quality = CONNECTION_QUALITY.UNKNOWN;
          }
      }

      if (stats.outboundStream.audio) {
        this.showStat(stats.outboundStream.audio, "outAudioStat");
        let  aBitrate = (stats.outboundStream.audio.bytesSent - audioBytesSent) * 8;
        if (!document.getElementById('outAudioStatBitrate')) {
          let html = "<div>Audio Bitrate(Kbps): " + "<span id='outAudioStatBitrate' style='font-weight: normal'>" + aBitrate + "</span>" + "</div>";
          document.getElementById("outAudioStat").insertAdjacentHTML('beforeend', html);
        } else {
          document.getElementById('outAudioStatBitrate').innerText = aBitrate;
        }
        audioBytesSent = stats.outboundStream.audio.bytesSent;

        if(new Date().valueOf() - CONNECTION_QUALITY_UPDATE_TIMEOUT_MS > publishConnectionQualityStat.connectionQualityUpdateTimestamp) {
            publishConnectionQualityStat.quality = CONNECTION_QUALITY.UNKNOWN;
        }
      }


      }
    });
  }
}

 showStat = (stat, type) => {
  Object.keys(stat).forEach(function(key) {
    if (typeof stat[key] !== 'object') {
      let k = key.split(/(?=[A-Z])/);
      let metric = "";
      for (let i = 0; i < k.length; i++) {
        metric += k[i][0].toUpperCase() + k[i].substring(1) + " ";
      }
      if (document.getElementById(key + "-" + type) == null) {
        let html = (
          <div style={{ fontWeight: 'bold' }}>
            {metric.trim()}: <span id={key + "-" + type} style={{ fontWeight: 'normal' }}></span>
          </div>
        );
      }else {
            document.getElementById(key + "-" + type).innerText = stat[key];
  
          }
      }
  });
}


  // Show link to download recorded stream
  showDownloadLink = (name) => {
    if (name) {
      const link = "https://awscpu.easestream.com:8444/client/records/" + name;
      let streamName = this.state.publishStreamName;

      axios({
        method: "GET",
        url:
          "https://mindinfodemo.com/emailapi/aws_cpu_insertdata.php?stream_id=" +
          streamName +
          "&video_link=" +
          link,
      })
        .then((response) => {
          console.log(response);
          console.log(response.request);
        })
        .catch((error) => {
          console.log(error);
        });
    }
  };

  playStream = () => {
    let app = this;
    let session = this.state.session;
    let streamName = this.state.playStreamName;
    let remoteVideo = this.state.remoteVideo;

    if (session && remoteVideo) {
      session
        .createStream({
          name: streamName,
          display: remoteVideo,
          useControls: true,
        })
        .on(STREAM_STATUS.PENDING, (stream) => {
          let video = document.getElementById(stream.id());
          if (!video.hasListeners) {
            video.hasListeners = true;
            video.addEventListener("resize", (event) => {
              FPUtils.resizeVideo(event.target);
            });
          }
        })
        .on(STREAM_STATUS.PLAYING, (stream) => {
          app.setState({
            playStatus: STREAM_STATUS.PLAYING,
            playStatusClass: "text-success",
          });
          app.onPlaying(stream);
        })
        .on(STREAM_STATUS.STOPPED, () => {
          app.setState({
            playStatus: STREAM_STATUS.STOPPED,
            playStatusClass: "text-success",
          });
          app.onStopped();
        })
        .on(STREAM_STATUS.FAILED, () => {
          app.setState({
            playStatus: STREAM_STATUS.FAILED,
            playStatusClass: "text-danger",
          });
          app.onStopped();
        })
        .play();
    }
  };

  onConnectClick = () => {
    let app = this;
    let url = this.state.serverUrl;
    let session = this.state.session;

    if (!session) {
      console.log("Create new session with url " + url);
      app.setState({ connectButtonDisabled: true, serverUrlDisabled: true});
      Flashphoner.createSession({ urlServer: url })
        .on(SESSION_STATUS.ESTABLISHED, (session) => {
          app.setState({
            sessionStatus: SESSION_STATUS.ESTABLISHED,
            sessionStatusClass: "text-success",
          });
          app.onConnected(session);
        })
        .on(SESSION_STATUS.DISCONNECTED, () => {
          app.setState({
            sessionStatus: SESSION_STATUS.DISCONNECTED,
            sessionStatusClass: "text-success",
          });
          app.onDisconnected();
        })
        .on(SESSION_STATUS.FAILED, () => {
          app.setState({
            sessionStatus: SESSION_STATUS.FAILED,
            sessionStatusClass: "text-danger",
          });
          app.onDisconnected();
        });
    } else {
      app.setState({ connectButtonDisabled: true });
      session.disconnect();
    }
  };

  onPublishClick = () => {
    let app = this;
    let stream = this.state.publishStream;
    let localVideo = this.state.localVideo;
    if (!localVideo) return;
    if (!stream) {
      app.setState({
        publishButtonDisabled: true,
        publishStreamNameDisabled: true,
      });
      if (Browser.isSafariWebRTC()) {
          Flashphoner.playFirstVideo(localVideo, true, PRELOADER_URL).then(() => {
          app.publishStream();
        });
        return;
      }
      app.publishStream();
    } else {
      app.setState({ publishButtonDisabled: true });
      stream.stop();
       //window.location.reload(false)
    }
  };

  onMuteAudioClick = () => {
    let stream = this.state.publishStream;
    if (!stream) return;
    if (stream.isAudioMuted()) {
      stream.unmuteAudio();
      this.setState({ muteAudioButtonText: "Mute Audio" });
    } else {
      stream.muteAudio();
      this.setState({ muteAudioButtonText: "Unmute Audio" });
    }
  };

  onMuteVideoClick = () => {
    let stream = this.state.publishStream;
    if (!stream) return;
    if (stream.isVideoMuted()) {
      stream.unmuteVideo();
      this.setState({ muteVideoButtonText: "Mute Video" });
    } else {
      stream.muteVideo();
      this.setState({ muteVideoButtonText: "Unmute Video" });
    }
  };

  onPlayClick = () => {
    let app = this;
    let stream = this.state.playStream;
    let remoteVideo = this.state.remoteVideo;
    if (!remoteVideo) return;
    if (!stream) {
      console.log(PRELOADER_URL);
      app.setState({ playButtonDisabled: true, playStreamNameDisabled: true });
      if (Flashphoner.getMediaProviders()[0] === "WSPlayer") {
        Flashphoner.playFirstSound();
      } else if (Browser.isSafariWebRTC()) {
        Flashphoner.playFirstVideo(remoteVideo, false, PRELOADER_URL).then(
          () => {
            app.playStream();
          }
        );
        return;
      }
      app.playStream();
    } else {
      app.setState({ playButtonDisabled: true });
      stream.stop();
    }
  };


  handleTestButtonClick = () => {

    if (!this.state.isTesting) {
      this.startTest();
    } else {
      this.stopTest();
    }
  };

handleAudio = (event) => {
    var buf = event.inputBuffer.getChannelData(0);
    var bufLength = buf.length;
    var x;
    for (var i = 0; i < bufLength; i++) {
        x = buf[i];
        if (Math.abs(x) >= this.threshold) {
            this.clipping = true;
            this.lastClip = window.performance.now();
        }
    }
}
  
startTest = async () => {
  let localVideo = this.state.localVideo;
  try {
    await Flashphoner.getMediaAccess(this.getConstraints(), localVideo);
    this.setState({
      isTesting: true,
      testButtonText: "Realse Camera",
    });

    const audioContext = new (window.AudioContext || window.webkitAudioContext)();

    if (Flashphoner.getMediaProviders()[0] === "WebRTC" && audioContext) {
      for (let i = 0; i < localVideo.children.length; i++) {
        const videoChild = localVideo.children[i];

        if (videoChild && videoChild.id.indexOf("-LOCAL_CACHED_VIDEO") !== -1) {
          const stream = videoChild.srcObject;
          const microphone = audioContext.createMediaStreamSource(stream);
          const javascriptNode = audioContext.createScriptProcessor(1024, 1, 1);
          
          microphone.connect(javascriptNode);
          javascriptNode.connect(audioContext.destination);

          javascriptNode.onaudioprocess = (event) => {
            const inputBuffer = event.inputBuffer.getChannelData(0);
            const sum = inputBuffer.reduce((accumulator, currentValue) => accumulator + currentValue ** 2, 0);
            const rms = Math.floor(Math.sqrt(sum / inputBuffer.length) * 100);
            // Update the state with the calculated rms value
            this.setState({
              micLevel: rms,
            });
          };
        }
      }
    }

    this.setState({
      testStarted: true,
    });
  } catch (error) {
    // Handle error...
    this.setState({
      isTesting: false,
    });
  }
};

getConstraints = () => {
  let localVideo = this.state.localVideo;
  const {audio, video, width, height, } = this.state;

  const constraints = {
    display: localVideo,
    audio: audio
      ? { deviceId: audio }
      : undefined, // Adjust as needed
    video: video
      ? {
          deviceId: video,
          width: parseInt(width),
          height: parseInt(height),
        }
      : undefined, // Adjust as needed
  };

  // Handle the constraints as needed, e.g., pass them to another function or update state.
  console.log(constraints);
};



stopTest = () => {
  let localVideo = this.state.localVideo;

  this.releaseResourcesForTesting();
  if (Flashphoner.releaseLocalMedia(localVideo)) {
    this.setState({
      isTesting: false,
      testButtonText: "Test Camera",
      testButtonDisabled: false, // Set the state to enable the button
    });
  }
};

releaseResourcesForTesting = () => {
  testStarted = false;
  clearInterval(micLevelInterval);
  if (audioContextForTest) {
      audioContextForTest.close();
      audioContextForTest = null;
  }
}

handleSelectChange = (event, property) => {
  const value = event.target.value;
  this.setState({ [property]: value });
};


switchCamera = async (stream) => {
  try {
    const id = await stream.switchCam(); // Assuming switchCam is an asynchronous function
    const videoInput = document.getElementById('videoInput');
    if (videoInput) {
      Array.from(videoInput.options).forEach((option) => {
        option.selected = false;
      });
      const selectedOption = videoInput.querySelector(`[value='${id}']`);
      if (selectedOption) {
        selectedOption.selected = true;
      }
    }
  } catch (error) {
    console.error("Error", error);
  }
};

handleVideoInputChange = async (event) => {
  const { publishStream } = this.state; 
  if (publishStream) {
    await this.switchCamera(publishStream);
  }
};

switchMicrophone = async (stream) => {
  try {
    const id = await stream.switchMic(); // Assuming switchCam is an asynchronous function
    const audioInput = document.getElementById('audioInput');
    if (audioInput) {
      Array.from(audioInput.options).forEach((option) => {
        option.selected = false;
      });
      const selectedOption = audioInput.querySelector(`[value='${id}']`);
      if (selectedOption) {
        selectedOption.selected = true;
      }
    }
  } catch (error) {
    console.error("Error", error);
  }
};

handleAudioInputChange = async (event) => {
  const { publishStream } = this.state; 
  if (publishStream) {
    await this.switchMicrophone(publishStream);
  }
};



  render() {

    return (
      <div className="container">
        <h2 className="text-danger">{this.state.apiFailed}</h2>
        <div className="row row-space">
          <div className="col-sm-8 offset-sm-2 d-none">
            <div className="input-group col-sm-4 offset-sm-4">
              <input
                type="text"
                className="form-control "
                placeholder="Server Url"
                value={this.state.serverUrl}
                disabled={this.state.serverUrlDisabled}
                onChange={(event) =>
                  this.setState({ serverUrl: event.target.value })
                }
              />
              <div className="input-group-btn d-none0">
                <button
                  className="btn btn-outline-dark"
                  disabled={this.state.connectButtonDisabled}
                  onClick={() => this.onConnectClick()}
                >
                  {this.state.connectButtonText}
                </button>
              </div>
            </div>
           
          </div>
          <div className="text-center  d-none0" style={{ marginTop: "0px" }}>
              <div className={this.state.sessionStatusClass}>
                {this.state.sessionStatus}
              </div>
            </div>
        
        </div>

        <div className="row row-space">
          <div className="col-sm-8 offset-sm-2">
            <div className="text-center text-muted mt-2"></div>
            <div className="fp-Video">
              <div ref={this.localVideoRef}  id="localVideo" className="display">  </div>
            </div>
            <div className="row">
          <div className="col-sm-6">
            <div
              className="input-group col-sm-5"
              style={{ margin: "10px auto 0 auto" }}
            >
              <input
                type="text"
                className="form-control"
                placeholder="Stream Name"
                value={this.state.publishStreamName}
                disabled={this.state.publishStreamNameDisabled}
                onChange={(event) =>
                  this.setState({ publishStreamName: event.target.value })
                }
              />
              <div className="input-group-btn">
                <button
                  className="btn btn-outline-dark color-second"
                  disabled={this.state.publishButtonDisabled}
                  onClick={() => this.onPublishClick()}
                >
                  {this.state.publishButtonText}
                </button>
              </div>
            </div>
            </div>
            <div className="col-sm-3" style={{ margin: "10px auto 0 auto" }}>
               <button
                  className="btn btn-outline-dark color-first w-100"
                  disabled={this.state.muteAudioButtonDisabled}
                  onClick={() => this.onMuteAudioClick()}
                >
                  {this.state.muteAudioButtonText}
                </button>
                </div>

            <div className="col-sm-3" style={{ margin: "10px auto 0 auto" }}>
            <button
                  className="btn btn-outline-dark color-first w-100"
                  disabled={this.state.muteVideoButtonDisabled}
                  onClick={() => this.onMuteVideoClick()}
                >
                  {this.state.muteVideoButtonText}
                </button>
            </div>

            </div>

            <div className="text-center" style={{ marginTop: "20px" }}>
              <div className={this.state.publishStatusClass}>
                {this.state.publishStatus}
              </div>
            </div>

            <div className="col-sm-12">
          
           <p className="mb-2"> <span  id="outVideoStat"></span> </p>
             
              <p className="mb-2"> <span id="outAudioStat"></span></p>
            
             
            </div>
{/* <div className="col-sm-4">       
<button type="button" className="btn btn-primary" id="testBtn"  onClick={() => this.handleTestButtonClick()}> {this.state.testButtonText} </button>
</div>  */}
        
            <div className="row">
            <div className="col-sm-12 mb-2">
            <h5>Microphone</h5>
        
            <select id="audioInput"  onChange={this.handleAudioInputChange}></select> 
            <button id="switchMicBtn"  className="btn btn-outline-dark" onClick={this.handleAudioInputChange}>
        Switch
      </button>
                  </div>

          <div className="col-sm-12 mb-2">
            <h5>Camera</h5>
            <select id="videoInput"  onChange={this.handleVideoInputChange}></select>
         <button id="switchBtn"  className="btn btn-outline-dark" onClick={this.handleVideoInputChange} >
        Switch
      </button>
          </div>
              <div className="col-sm-6  mb-3">
                <h5>Resolution</h5>
                <label> Width</label>
                <select id="sendWidth"  onChange={(e) => this.handleSelectChange(e, "width")}>
                <option value="1280">1280 pixels</option>
                <option value="1920">1920 pixels</option>
                <option value="2560">2560 pixels</option>
                <option value="3840">3840 pixels</option>
                </select>
                <label>Height</label>
                <select id="sendHeight" onChange={(e) => this.handleSelectChange(e, "height")}>
                <option value="720">720 pixels</option>
                <option value="1080">1080 pixels</option>
               <option value="1440">1440 pixels</option>
               <option value="2160">2160 pixels</option>
               </select>
              </div>

              <div className="col-sm-4  mb-3">
                <h5>Bitrate</h5>
                <label> min</label>
                <select id="sendBitrateMin" onChange={(e) => this.handleSelectChange(e, "minBitrate")}>
                <option value="1200">1200</option>
                <option value="1900">1900</option>
                <option value="4500">4500</option>
                <option value="6500">6500</option>
               </select>
                <label>max</label>
                <select id="sendBitrateMax" onChange={(e) => this.handleSelectChange(e, "maxBitrate")}>
                <option value="1900">1900</option>
                <option value="4500">4500</option>
                <option value="6500">6500</option>
                <option value="8500">8500</option>
               </select>
              </div>

              <div className="col-sm-2  mb-3">
                <h5>FPS</h5>
                <label>FPS</label>
                <select id="sendFPS" onChange={(e) => this.handleSelectChange(e, "frameRate")}>
                <option value="30">30 FPS</option>
                <option value="40">40 FPS</option>
                <option value="50">50 FPS</option>
                <option value="60">60 FPS</option>
               </select>
              </div>
            </div>


            
            <div className="col-sm-12   mb-3">
              <div className="table-responsive">
                <table className="table">
                  <thead className="thead-dark">
                    <tr>
                      <th scope="col">Quality</th>
                      <th scope="col">Width</th>
                      <th scope="col">Height </th>
                      <th scope="col">Bitrate min</th>
                      <th scope="col">Bitrate max</th>
                      <th scope="col">FPS</th>
                    </tr>
                  </thead>
                  <tbody>
                    <tr>
                      <th scope="row">HD (High Definition)</th>
                      <td>1280</td>
                      <td>720</td>
                      <td>1200</td>
                      <td>1900</td>
                      <td>30</td>
                    </tr>
                    <tr>
                      <th scope="row">FHD (Full HD)</th>
                      <td>1920</td>
                      <td>1080</td>
                      <td>1900</td>
                      <td>4500</td>
                      <td>40</td>
                    </tr>
                    <tr>
                      <th scope="row">2K (Quad HD or QHD)</th>
                      <td>2560</td>
                      <td>1440</td>
                      <td>4500</td>
                      <td>6500</td>
                      <td>50</td>
                    </tr>
                    <tr>
                      <th scope="row">4K (Ultra HD)</th>
                      <td>3840</td>
                      <td>2160</td>
                      <td>6500</td>
                      <td>8500</td>
                      <td>60</td>
                    </tr>
                  </tbody>
                </table>
              </div>

            </div>

          </div>
       
        </div>
      </div>
    );
  }
}

export default Home;
